@@ -1,6 +1,6 @@
 package WebService::Reddit;
-$WebService::Reddit::VERSION = '0.000002';
-use Moo;
+$WebService::Reddit::VERSION = '0.000003';
+use Moo 2.003000;
 use MooX::StrictConstructor;
 
 use Types::Standard qw( Bool InstanceOf Int Str );
@@ -61,23 +61,28 @@ has ua => (
     default => sub { WWW::Mechanize->new( autocheck => 0 ) },
 );
 
-# Make a whole bunch of unsafe assumptions
 sub get {
-    my $self     = shift;
-    my $relative = URI->new(shift);
+    my $self = shift;
+    my $uri  = $self->_normalize_uri(@_);
 
-    my $uri = $self->_base_uri->clone;
-    $uri->path( $relative->path );
-    $uri->path_query( $relative->path_query ) if $relative->path_query;
+    return $self->_perform_request(
+        sub { $self->ua->get( $uri, $self->_auth ) } );
+}
 
-    my $res = WebService::Reddit::Response->new(
-        raw => $self->ua->get( $uri, $self->_auth ) );
-    if ( $res->code == 401 ) {
-        $self->refresh_access_token;
-        $res = WebService::Reddit::Response->new(
-            raw => $self->ua->get( $uri, $self->_auth ) );
-    }
-    return $res;
+sub post {
+    my $self = shift;
+    my $uri  = $self->_normalize_uri(shift);
+    my $form = shift;
+
+    return $self->_perform_request(
+        sub { $self->ua->post( $uri, $form, $self->_auth ) } );
+}
+
+sub delete {
+    my $self = shift;
+    my $uri  = $self->_normalize_uri(@_);
+    return $self->_perform_request(
+        sub { $self->ua->delete( $uri, $self->_auth ) } );
 }
 
 sub _auth {
@@ -85,6 +90,31 @@ sub _auth {
     return ( Authorization => 'bearer ' . $self->access_token );
 }
 
+sub _normalize_uri {
+    my $self   = shift;
+    my $path   = shift;
+    my $params = shift;
+
+    my $relative_uri = URI->new($path);
+    my $uri          = $self->_base_uri->clone;
+    $uri->path( $relative_uri->path );
+    $uri->query_form($params) if keys %{$params};
+
+    return $uri;
+}
+
+sub _perform_request {
+    my $self = shift;
+    my $cb   = shift;
+
+    my $res = WebService::Reddit::Response->new( raw => $cb->() );
+    if ( $res->code == 401 ) {
+        $self->refresh_access_token;
+        $res = WebService::Reddit::Response->new( raw => $cb->() );
+    }
+    return $res;
+}
+
 sub refresh_access_token {
     my $self = shift;
     $self->ua->credentials( $self->_app_key, $self->_app_secret );
@@ -124,7 +154,7 @@ WebService::Reddit - Thin wrapper around the Reddit OAuth API
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
@@ -187,13 +217,31 @@ the Reddit OAuth endpoint.
 
 =head2 get
 
-Returns a L<WebService::Reddit::Response> object.  Accepts an URL (or L<URI>
-object), which may or may not include GET params.  You should provide a
-relative URL.  If you provide an absolute URL, your scheme and host will get
-clobbered with the C<base_uri>.
+Accepts a relative URL path and an optional HashRef of params.  Returns a
+L<WebService::Reddit::Response> object.
 
-    my $me        = $client->get('/api/v1/me');
-    my $new_posts = $client->get('/r/perl/new?limit=25');
+    my $me = $client->get('/api/v1/me');
+    my $new_posts = $client->get( '/r/perl/new', { limit => 25 } );
+
+=head2 delete
+
+Accepts a relative URL path and an optional HashRef of params.  Returns a
+L<WebService::Reddit::Response> object.
+
+    my $delete = $client->delete(
+        '/api/v1/me/friends/randomusername',
+        { id => 'someid' }
+    );
+
+=head2 post
+
+Accepts a relative URL path and an optional HashRef of params.  Returns a
+L<WebService::Reddit::Response> object.
+
+    my $post = $reddit->post(
+        '/api/search_reddit_names',
+        { exact => 1, query => 'perl' }
+    );
 
 =head2 access_token
 
